@@ -135,6 +135,7 @@ class Aviary(bullet_client.BulletClient):
         """
         Steps the environment
         """
+        self.collisions = set()
         for i in range(self.ctrl_update_ratio):
 
             # wait a bit if we're rendering
@@ -169,5 +170,8 @@ class Aviary(bullet_client.BulletClient):
 
             self.stepSimulation()
 
-        self.performCollisionDetection()
+            # splice out collisions
+            for collision in self.getContactPoints():
+                self.collisions.add([collision.bodyUniqueIdA, collision.bodyUniqueIdB])
+
         self.steps += 1
